@@ -1,5 +1,5 @@
-use Result;
-use compact1::index::Index;
+use crate::compact1::index::Index;
+use crate::Result;
 
 index! {
     #[doc = "A name index."]
