@@ -1,8 +1,8 @@
 use std::io::Cursor;
 use std::mem;
 
-use {Result, Tape};
-use type2::{number, Operand, Operation, Operator};
+use crate::type2::{number, Operand, Operation, Operator};
+use crate::{Result, Tape};
 
 /// A program.
 pub struct Program<'l> {
@@ -35,9 +35,9 @@ impl<'l> Program<'l> {
     }
 
     /// Return the next operation.
-    #[allow(unused_comparisons)]
+    #[allow(unused_comparisons, unused_must_use)]
     pub fn next(&mut self) -> Result<Option<Operation>> {
-        use type2::Operator::*;
+        use crate::type2::Operator::*;
 
         if self.routine.done()? {
             return Ok(None);
@@ -79,7 +79,7 @@ impl<'l> Program<'l> {
         loop {
             code = self.routine.peek::<u8>()?;
             match code {
-                0x1c | 0x20...0xff => push!(self.routine.take_operand()?),
+                0x1c | 0x20..=0xff => push!(self.routine.take_operand()?),
                 _ => break,
             }
         }
